@@ -1,4 +1,4 @@
-noffspring<-function(cand, N){
+noffspring<-function(cand, N, random=TRUE){
   candAsDataTable <- "data.table" %in% class(cand)
   cand <- as.data.frame(cand)
   if(candAsDataTable){setDF(cand)}
@@ -19,7 +19,11 @@ noffspring<-function(cand, N){
     rest     <- 2*N*oc[sex==s]-noffs
     nMissing <- N-sum(noffs)
     if(nMissing>0){
-      index  <- rev(order(rest))[1:nMissing]
+      if(random){
+        index  <- sample(1:sum(sex==s), size=nMissing, replace=FALSE, prob=rest)
+      }else{
+        index  <- rev(order(rest))[1:nMissing]
+      }
       noffs[index] <- noffs[index]+1
     }
     noff[sex==s]<-noffs
