@@ -47,9 +47,9 @@ Rcpp::NumericMatrix rcpp_segIBDandNVersion2(std::string pathThisBreed, int NFile
   
   for(i=0; i<NC;i++){
     indexC[i] = ArmaIndexC.at(i);
-    fROH[i]   = (double*)calloc(NC,sizeof(double));
-    thisROH[i]= (int*)calloc(NC,sizeof(int));
-    Nat[i]    = (int*)calloc(M,sizeof(int));
+    fROH[i]   = (double*)calloc(i+1, sizeof(double));
+    thisROH[i]=    (int*)calloc(i+1, sizeof(int));
+    Nat[i]    =    (int*)calloc(M,   sizeof(int));
     if(fROH[i]    == NULL){error_return("Memory allocation failed.");};
     if(thisROH[i] == NULL){error_return("Memory allocation failed.");};
     if(Nat[i]     == NULL){error_return("Memory allocation failed.");};
@@ -90,7 +90,7 @@ Rcpp::NumericMatrix rcpp_segIBDandNVersion2(std::string pathThisBreed, int NFile
     if(rK==0){break;}
 
     for(i=0; i<NC;i++){
-      for(j=i; j<NC; j++){
+      for(j=0; j<i+1; j++){
         if(currAllelesC[i]==currAllelesC[j]){
           if(prevAllelesC[i]==prevAllelesC[j] && m>0){ /* ROH verlängern */
             thisROH[i][j] += rK;
@@ -137,7 +137,7 @@ Rcpp::NumericMatrix rcpp_segIBDandNVersion2(std::string pathThisBreed, int NFile
   
   
   for(i=0; i<NC;i++){
-    for(j=i; j<NC; j++){
+    for(j=0; j<i+1; j++){
       if(thisROH[i][j]>=minSNP){
         L = Pos[M]-Pos[M-thisROH[i][j]];
         if(L>=minL){
